function [w,X]=dtft(x,Fs)
% DTFT takes the DTFT of a sequence or sampled signal
% [w,X]=dtft(x) returns the dtft of x at the frequencies w
% [f,X]=dtft(x,Fs) returns the DTFT of sampled signal x
%     sampled at Fs Hz.  
% If no output arguments are requested, the function plots the 
%    results.

if nargin==1  % If only 1 input argument (ie not sampled)
    Fs=2*pi;  %  2pi is the highest digital signal frequency
end

% zero pad x if needed to make it long enough
x = x(:)';    % guarantee it is a row vector
L=length(x);
if L<1001     % guarantee it is at least 1001 long
    x = [x zeros(1,1001-L)];
end
L=length(x);
if rem(L,2)==0 % guarantee it is an odd length
    x = [x 0];
end
L=length(x);

% take fft of x and drop the high freq mirror symmetry part
X1 = fft(x);
X1((L+1)/2+1:end)=[];

% make the appropriate omega vector
omega = linspace(0,Fs*(L-1)/L,L);
omega((L+1)/2+1:end)=[];

% if no output requested, plot it
if nargout == 0
    plot(omega, abs(X1))
    xlabel('frequency')
    ylabel('amplitude')
    title('magnitude of the DTFT of x[n]')
    figure(gcf)
else
    w = omega;
    X = X1;
end

